# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from eventstat.models import (
    EventstatDetail,
    EventstatLog,
    EventstatImage,
    EventstatMachine,
    EventstatMetric,
    EventstatUpgrade,
    EventstatResult,
)

from django.contrib import admin


class EventstatUpgradeAdmin(admin.ModelAdmin):
    list_display = (
        'release',
        'variant',
        'arch',
        'from_release',
        'date',
    )

    list_filter = [
        'release',
        'variant',
        'arch',
        'from_release',
        'date',
    ]
    search_fields = [
        'release',
        'variant',
        'arch',
        'from_release',
    ]
    ordering = ['-date']


class EventstatMachineAdmin(admin.ModelAdmin):
    list_display = ('name', 'mac_address')
    search_fields = ['name', 'mac_address']


class EventstatLogAdmin(admin.ModelAdmin):
    list_display = ('name', 'path')
    search_fields = ['name', 'path']


class EventstatMetricAdmin(admin.ModelAdmin):
    list_display = (
        'name',
        'image',
        'upgrade',
        'minimum',
        'maximum',
        'average',
        'stddev',
    )
    list_filter = [
        'name',
        'image',
        'upgrade',
    ]
    search_fields = [
        'upgrade',
        'name',
    ]


class EventstatImageAdmin(admin.ModelAdmin):
    list_display = (
        'release',
        'variant',
        'arch',
        'build_number',
        'image_type',
    )
    list_filter = [
        'release',
        'variant',
        'arch',
        'build_number',
    ]
    search_fields = [
        'release',
        'variant',
        'arch',
        'build_number',
    ]


class EventstatDetailAdmin(admin.ModelAdmin):
    list_display = (
        'image',
        'upgrade',
        'task',
        'total',
    )


class EventstatResultAdmin(admin.ModelAdmin):
    list_display = (
        'image',
        'upgrade',
        'machine',
        'kernel',
    )


admin.site.register(EventstatUpgrade, EventstatUpgradeAdmin)
admin.site.register(EventstatMachine, EventstatMachineAdmin)
admin.site.register(EventstatLog, EventstatLogAdmin)
admin.site.register(EventstatMetric, EventstatMetricAdmin)
admin.site.register(EventstatImage, EventstatImageAdmin)
admin.site.register(EventstatDetail, EventstatDetailAdmin)
admin.site.register(EventstatResult, EventstatResultAdmin)
