# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import django_tables2 as tables

from memevent.models import (
    MemoryEventDetail,
    MemoryEventImage,
)


class DetailTable(tables.Table):

    class Meta:
        attrs = {'class': 'basic wide'}
        model = MemoryEventDetail
        fields = (
            'command',
            'pss',
            'uss',
            'rss',
            'swap',
            'user',
        )

    pss = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '{{ record.pss|binary_suffix }}',
    )

    uss = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '{{ record.uss|binary_suffix }}',
    )

    rss = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '{{ record.rss|binary_suffix }}',
    )

    swap = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '{{ record.swap|binary_suffix }}',
    )


class EventDetailTable(tables.Table):

    class Meta:
        attrs = {'class': 'basic wide'}
        model = MemoryEventDetail
        fields = (
            'run',
            'command',
            'pss',
            'uss',
            'rss',
            'swap',
            'user',
        )
        order_by = ('run',)

    command = tables.TemplateColumn(
        '<a href="{{ record.jenkins_build.url }}">{{ record.command }}</a>'
    )

    pss = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '{{ record.pss|binary_suffix }}',
    )

    uss = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '{{ record.uss|binary_suffix }}',
    )

    rss = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '{{ record.rss|binary_suffix }}',
    )

    swap = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '{{ record.swap|binary_suffix }}',
    )


class ArchOverviewTable(tables.Table):

    class Meta:
        attrs = {'class': 'basic wide'}
        model = MemoryEventImage
        fields = (
            'build_number',
            'release',
            'variant',
            'events',
        )

    build_number = tables.TemplateColumn(
        '<a href="{% url memevent_image_overview record.id %}">'
        '{{ record.build_number }}</a>',
    )
    events = tables.Column()


class ImageOverviewTable(tables.Table):

    class Meta:
        attrs = {'class': 'basic wide'}
        model = MemoryEventImage
        fields = (
            'event',
            'pss_sum',
        )
        order_by = ('pss_sum',)

    pss_sum = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '{{ record.pss_sum|binary_suffix }}',
        verbose_name="PSS Average",
    )
    event = tables.TemplateColumn(
        '<a href="{% url memevent_event_detail record.id '
        'record.memoryeventdetail__event %}">'
        '{{ record.memoryeventdetail__event }}</a>'
    )
