# QA Dashboard
# Copyright 2013 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import django_tables2 as tables
from django_tables2.utils import Accessor as A


class SmokeBaseTable(tables.Table):
    class Meta:
        attrs = {'class': 'basic wide'}
        fields = (
            'total_count',
            'pass_count',
            'fail_count',
            'error_count',
            'pass_rate',
            'bugs',
        )

    total_count = tables.Column(attrs={'td': {'class': 'num'}})
    pass_count = tables.Column(attrs={'td': {'class': 'num'}})
    fail_count = tables.Column(attrs={'td': {'class': 'num'}})
    error_count = tables.TemplateColumn(
        '{% if record.error_count > 0 and record.bugs|length = 0 %}'
        '<div class="error-14x14 smaller-icon icon"></div>{% endif %}'
        '{{ record.error_count }}',
        attrs={'td': {'class': 'num'}},
    )
    pass_rate = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '{{ record.pass_rate|decimal_to_percent }}',
        attrs={'td': {'class': 'num'}},
    )
    td_class_extra = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '{{ record.pass_rate|pass_rate_color }}',
        visible=False,
    )
    bugs = tables.TemplateColumn(
        '{% load dashboard_extras %}'
        '{{ record.bugs|bug_list_numbers|safe }}',
        accessor=A('bugs'),
        order_by=('bugs',),
    )


class SmokeImageTable(SmokeBaseTable):
    class Meta(SmokeBaseTable.Meta):
        order_by = ('-build_number', 'variant', 'arch')
        fields = (
            'build_number',
            'variant',
            'arch',
        ) + SmokeBaseTable.Meta.fields

    build_number = tables.LinkColumn(
        'smokeng.views.image_overview',
        kwargs={
            "release": A('release'),
            "image_id": A('image_id'),
        }
    )
    variant = tables.Column()
    arch = tables.Column()


class SmokeResultTable(SmokeBaseTable):
    class Meta(SmokeBaseTable.Meta):
        order_by = ('-ran_at', 'name',)
        fields = (
            'name',
            'ran_at',
        ) + SmokeBaseTable.Meta.fields

    name = tables.TemplateColumn(
        '<a href="{{ record.jenkins_build__job__url }}'
        '{{ record.jenkins_build__build_number }}">{{ record.name }}</a>'
    )
    ran_at = tables.Column()
    logs = tables.TemplateColumn(
        '<a href="{{ record.jenkins_build__job__url }}'
        '{{ record.jenkins_build__build_number }}/artifact/">Artifacts</a>'
        '&nbsp;&nbsp;&nbsp;'
        '<a href="{{ record.jenkins_build__job__url }}'
        '{{ record.jenkins_build__build_number }}/console">Console Log</a>',
        sortable=False
    )


class SmokeKPITable(tables.Table):
    class Meta:
        order_by = ('arch')

    arch = tables.Column()
    build_number = tables.Column(
        verbose_name="Build",
    )
    pass_rate = tables.TemplateColumn(
        '{{ record.pass_rate|floatformat }}%',
        attrs={'td': {'class': 'num'}},
    )
